[svn-commits] file: branch 1.2 r45265 - in /branches/1.2: channels/ configs/

svn-commits at lists.digium.com svn-commits at lists.digium.com
Mon Oct 16 12:59:54 MST 2006


Author: file
Date: Mon Oct 16 14:59:54 2006
New Revision: 45265

URL: http://svn.digium.com/view/asterisk?rev=45265&view=rev
Log:
Use responses rather then replies even though they mean the same thing.

Modified:
    branches/1.2/channels/chan_sip.c
    branches/1.2/configs/sip.conf.sample

Modified: branches/1.2/channels/chan_sip.c
URL: http://svn.digium.com/view/asterisk/branches/1.2/channels/chan_sip.c?rev=45265&r1=45264&r2=45265&view=diff
==============================================================================
--- branches/1.2/configs/sip.conf.sample (original)
+++ branches/1.2/configs/sip.conf.sample Mon Oct 16 14:59:54 2006
@@ -111,7 +111,7 @@
 		    		; for any reason, always reject with '401 Unauthorized'
 				; instead of letting the requester know whether there was
 				; a matching user or peer for their request
-;ignoreoodreplies = no          ; If no then out of dialog replies will not be ignored
+;ignoreoodresponses = no        ; If no then out of dialog responses will not be ignored
 ;
 ; If regcontext is specified, Asterisk will dynamically create and destroy a
 ; NoOp priority 1 extension for a given peer who registers or unregisters with



More information about the svn-commits mailing list
--- branches/1.2/channels/chan_sip.c (original)
+++ branches/1.2/channels/chan_sip.c Mon Oct 16 14:59:54 2006
@@ -373,7 +373,7 @@
 static int global_reg_timeout = DEFAULT_REGISTRATION_TIMEOUT;	
 static int global_regattempts_max = 0;
 
-static int global_ignoreoodreplies = 1;
+static int global_ignoreoodresponses = 1;
 
 /* Object counters */
 static int suserobjs = 0;
@@ -3241,8 +3241,8 @@
 	}
 	ast_mutex_unlock(&iflock);
 
-	/* If this is a response and we have ignoring of out of dialog replies turned, then drop it */
-	if (req->method == SIP_RESPONSE && global_ignoreoodreplies)
+	/* If this is a response and we have ignoring of out of dialog responses turned on, then drop it */
+	if (req->method == SIP_RESPONSE && global_ignoreoodresponses)
 		return NULL;
 
 	p = sip_alloc(callid, sin, 1, intended_method);
@@ -8311,7 +8311,7 @@
 	ast_cli(fd, "  Videosupport:           %s\n", videosupport ? "Yes" : "No");
 	ast_cli(fd, "  AutoCreatePeer:         %s\n", autocreatepeer ? "Yes" : "No");
 	ast_cli(fd, "  Allow unknown access:   %s\n", global_allowguest ? "Yes" : "No");
-	ast_cli(fd, "  Drop misc replies:      %s\n", global_ignoreoodreplies ? "Yes" : "No");
+	ast_cli(fd, "  Drop misc responses:    %s\n", global_ignoreoodresponses ? "Yes" : "No");
 	ast_cli(fd, "  Promsic. redir:         %s\n", ast_test_flag(&global_flags, SIP_PROMISCREDIR) ? "Yes" : "No");
 	ast_cli(fd, "  SIP domain support:     %s\n", AST_LIST_EMPTY(&domain_list) ? "No" : "Yes");
 	ast_cli(fd, "  Call to non-local dom.: %s\n", allow_external_domains ? "Yes" : "No");
@@ -11955,11 +11955,11 @@
 		ast_set_flag(mask, SIP_PROMISCREDIR);
 		ast_set2_flag(flags, ast_true(v->value), SIP_PROMISCREDIR);
 		res = 1;
-	} else if (!strcasecmp(v->name, "ignoreoodreplies")) {
+	} else if (!strcasecmp(v->name, "ignoreoodresponses")) {
 		if (ast_true(v->value))
-			global_ignoreoodreplies = 1;
+			global_ignoreoodresponses = 1;
 		else
-			global_ignoreoodreplies = 0;
+			global_ignoreoodresponses = 0;
 	}
 
 	return res;
@@ -12612,7 +12612,7 @@
 	tos = 0;
 	expiry = DEFAULT_EXPIRY;
 	global_allowguest = 1;
-	global_ignoreoodreplies = 1;
+	global_ignoreoodresponses = 1;
 
 	/* Read the [general] config section of sip.conf (or from realtime config) */
 	v = ast_variable_browse(cfg, "general");

Modified: branches/1.2/configs/sip.conf.sample
URL: http://svn.digium.com/view/asterisk/branches/1.2/configs/sip.conf.sample?rev=45265&r1=45264&r2=45265&view=diff
==============================================================================